@@ -10,6 +10,8 @@
 #include <wlr/types/wlr_touch.h>
 #include <wlr/types/wlr_tablet_tool.h>
 #include "seat.h"
+#include "event.h"
+#include "gesture.h"
 
 #include <glib-object.h>
 
@@ -31,6 +33,18 @@ typedef enum {
 
 typedef struct _PhocSeatView PhocSeatView;
 
+/**
+ * PhocTouchPoint:
+ *
+ * A touch point tracked compositor side.
+ */
+typedef struct PhocTouchPoint {
+  int   touch_id;
+
+  double lx;
+  double ly;
+} PhocTouchPoint;
+
 /* TODO: we keep the struct public due to the list links and
    notifiers but we should avoid other member access */
 typedef struct _PhocCursor {
@@ -71,6 +85,7 @@ typedef struct _PhocCursor {
   struct wl_listener                touch_down;
   struct wl_listener                touch_up;
   struct wl_listener                touch_motion;
+  struct wl_listener                touch_frame;
 
   struct wl_listener                tool_axis;
   struct wl_listener                tool_tip;
@@ -82,6 +97,8 @@ typedef struct _PhocCursor {
   struct wl_listener                focus_change;
 
   struct wl_listener                constraint_commit;
+
+
 } PhocCursor;
 
 PhocCursor *phoc_cursor_new (PhocSeat                                                    *seat);
@@ -108,3 +125,14 @@ void        phoc_cursor_constrain (PhocCursor
 				   double                                                 sx,
 				   double                                                 sy);
 void        phoc_maybe_set_cursor (PhocCursor                                            *self);
+void        phoc_cursor_handle_event             (PhocCursor                             *self,
+                                                  PhocEventType                           type,
+                                                  gpointer                                event,
+                                                  gsize                                   size);
+
+void        phoc_cursor_add_gesture              (PhocCursor                             *self,
+                                                  PhocGesture                            *gesture);
+GSList     *phoc_cursor_get_gestures             (PhocCursor                             *self);
+
+gboolean    phoc_cursor_is_active_touch_id       (PhocCursor                             *self,
+                                                  int                                     touch_id);
