@@ -21,7 +21,7 @@ const char        *phoc_input_get_device_type (enum wlr_input_device_type type);
 PhocSeat          *phoc_input_get_seat (PhocInput *self, char *name);
 void               phoc_input_update_cursor_focus (PhocInput *self);
 PhocSeat          *phoc_input_seat_from_wlr_seat (PhocInput       *self,
-                                                  struct wlr_seat *seat);
+                                                  struct wlr_seat *wlr_seat);
 GSList *           phoc_input_get_seats          (PhocInput *self);
 PhocSeat          *phoc_input_get_last_active_seat (PhocInput *self);
 
