@@ -1,9 +1,11 @@
 #pragma once
 
+#include "gesture.h"
+
 #include <stdbool.h>
-#include <wlr/types/wlr_box.h>
 #include <wlr/types/wlr_surface.h>
 #include <wlr/types/wlr_layer_shell_v1.h>
+#include <wlr/util/box.h>
 #include "output.h"
 #include "layer-surface.h"
 
@@ -15,11 +17,11 @@ enum layer_parent {
 	LAYER_PARENT_SUBSURFACE
 };
 
-struct roots_layer_popup {
+typedef struct phoc_layer_popup {
 	enum layer_parent parent_type;
 	union {
 		PhocLayerSurface *parent_layer;
-		struct roots_layer_popup *parent_popup;
+		struct phoc_layer_popup *parent_popup;
 	};
 
 	struct wlr_xdg_popup *wlr_popup;
@@ -29,15 +31,15 @@ struct roots_layer_popup {
 	struct wl_listener commit;
 	struct wl_listener new_popup;
 	struct wl_listener new_subsurface;
-	struct wl_list subsurfaces; // roots_layer_subsurface::link
-};
+	struct wl_list subsurfaces; // phoc_layer_subsurface::link
+} PhocLayerPopup;
 
-struct roots_layer_subsurface {
+typedef struct phoc_layer_subsurface {
 	enum layer_parent parent_type;
 	union {
 		PhocLayerSurface *parent_layer;
-		struct roots_layer_popup *parent_popup;
-		struct roots_layer_subsurface *parent_subsurface;
+		struct phoc_layer_popup *parent_popup;
+		struct phoc_layer_subsurface *parent_subsurface;
 	};
 	struct wl_list link;
 
@@ -47,8 +49,8 @@ struct roots_layer_subsurface {
 	struct wl_listener destroy;
 	struct wl_listener commit;
 	struct wl_listener new_subsurface;
-	struct wl_list subsurfaces; // roots_layer_subsurface::link
-};
+	struct wl_list subsurfaces; // phoc_layer_subsurface::link
+} PhocLayerSubsurface;
 
 void phoc_layer_shell_arrange (PhocOutput *output);
 void phoc_layer_shell_update_focus (void);
